@@ -2,5 +2,7 @@
 
 
 def present(obj) -> bool:
-    """Check if the object is not None."""
+    """Check if the object is not None.
+
+    obj: the object to check"""
     return obj is not None
